import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["agents", "valueMode", "value", "onChange", "disabled", "readOnly", "placeholder"];
import React, { useCallback, useMemo } from "react";
import { Select, Tag } from "udesk-ui";
export var modeEnums;

(function (modeEnums) {
  modeEnums["Multiple"] = "multiple";
})(modeEnums || (modeEnums = {}));

var AgentSelect = /*#__PURE__*/React.memo(function (props) {
  var _props$agents = props.agents,
      agents = _props$agents === void 0 ? [] : _props$agents,
      _props$valueMode = props.valueMode,
      valueMode = _props$valueMode === void 0 ? modeEnums.Multiple : _props$valueMode,
      value = props.value,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
      disabled = props.disabled,
      readOnly = props.readOnly,
      placeholder = props.placeholder,
      restProps = _objectWithoutPropertiesLoose(props, _excluded);

  var options = useMemo(function () {
    return agents.map(function (i) {
      return _extends({}, i, {
        value: i.id,
        label: i.nick_name
      });
    });
  }, [agents]);
  var isMulValue = useMemo(function () {
    return valueMode === modeEnums.Multiple;
  }, [valueMode]);
  var selectValue = useMemo(function () {
    var _formattedValueArr;

    // 无论单选多选都转换为数组做处理
    var formattedValueArr;

    if (typeof value === 'string' && value) {
      formattedValueArr = value.split(',');
    } else if (typeof value === 'number') {
      formattedValueArr = [value];
    } else if (Array.isArray(value)) {
      formattedValueArr = value;
    } else {
      formattedValueArr = [];
    } // value需要和option的值是同一种类型


    return (_formattedValueArr = formattedValueArr) == null ? void 0 : _formattedValueArr.map(function (value) {
      return value && isNaN(Number(value)) ? value : Number(value);
    });
  }, [isMulValue, value]);
  var selectData = useMemo(function () {
    var selectOptions = options.filter(function (item) {
      return selectValue.includes(item.value);
    });
    return selectOptions;
  }, [isMulValue, selectValue]);
  var handleChange = useCallback(function (value, options) {
    onChange(formatValueToString(value), options);
  }, []);
  var handleFilter = useCallback(function (input, option) {
    return (option == null ? void 0 : option.nick_name.toLowerCase().indexOf(input.toLowerCase())) > -1 || (option == null ? void 0 : option.agent_name_pinyin.toLowerCase().indexOf(input.toLowerCase())) > -1;
  }, []);
  var readOnlyEle = useMemo(function () {
    if (!selectData.length) {
      return /*#__PURE__*/React.createElement("span", null, "- -");
    }

    return selectData.map(function (item) {
      if (isMulValue) {
        return /*#__PURE__*/React.createElement(Tag, {
          className: "custom-tag"
        }, (item == null ? void 0 : item.label) || '');
      }

      return /*#__PURE__*/React.createElement("span", null, (item == null ? void 0 : item.label) || '');
    });
  }, [selectData, isMulValue]);

  if (readOnly) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, readOnlyEle);
  }

  return /*#__PURE__*/React.createElement(Select, _extends({}, restProps, {
    showSearch: true,
    allowClear: true,
    style: {
      width: '100%'
    },
    mode: valueMode,
    disabled: disabled,
    value: selectValue,
    placeholder: placeholder,
    onChange: handleChange,
    filterOption: handleFilter,
    options: options
  }));
});
AgentSelect.defaultProps = {
  disabled: false,
  readOnly: false,
  dropdownMatchSelectWidth: false,
  onChange: function onChange() {}
}; // 为了兼容原有数据结构,原数据格式为字符串(自定义字段使用)

function formatValueToString(value) {
  if (Array.isArray(value)) {
    return value.join(',');
  }

  return value;
}

export default AgentSelect;